#[unsafe(no_mangle)]pub extern "C" fn time_event_accumulator_clear(
accumulator: &mut TimeEventAccumulator_API,
)Expand description
Clears all events from the accumulator heap without deallocating the accumulator itself.
#[unsafe(no_mangle)]pub extern "C" fn time_event_accumulator_clear(
accumulator: &mut TimeEventAccumulator_API,
)Clears all events from the accumulator heap without deallocating the accumulator itself.